@@ -810,9 +810,9 @@ gconf_load_source_path(const gchar* filename, GError** err)
     {
       if (err)
         *err = gconf_error_new(GCONF_ERROR_FAILED,
-                                _("Couldn't open path file `%s': %s\n"), 
-                                filename, 
-                                strerror(errno));
+                               _("Couldn't open path file `%s': %s\n"), 
+                               filename, 
+                               strerror(errno));
       return NULL;
     }
 
@@ -835,13 +835,18 @@ gconf_load_source_path(const gchar* filename, GError** err)
         {
           gchar* unq;
           gchar** included;
-
+          gchar *varsubst;
+          
           s += 7;
 
           unq = unquote_string(s);
 
-          included = gconf_load_source_path(unq, NULL);
+          varsubst = subst_variables (unq);
+          
+          included = gconf_load_source_path (varsubst, NULL);
 
+          g_free (varsubst);
+          
           if (included != NULL)
             {
               gchar** iter = included;
@@ -865,7 +870,7 @@ gconf_load_source_path(const gchar* filename, GError** err)
           
           if (*varsubst != '\0') /* Drop lines with just two quote marks or something */
             {
-              gconf_log(GCL_INFO, _("Adding source `%s'\n"), varsubst);
+              gconf_log(GCL_DEBUG, _("Adding source `%s'\n"), varsubst);
               l = g_slist_prepend(l, g_strdup(varsubst));
             }
           g_free(varsubst);
@@ -877,9 +882,9 @@ gconf_load_source_path(const gchar* filename, GError** err)
       /* This should basically never happen */
       if (err)
         *err = gconf_error_new(GCONF_ERROR_FAILED,
-                                _("Read error on file `%s': %s\n"), 
-                                filename,
-                                strerror(errno));
+                               _("Read error on file `%s': %s\n"), 
+                               filename,
+                               strerror(errno));
       /* don't return, we want to go ahead and return any 
          addresses we already loaded. */
     }
@@ -2156,9 +2161,9 @@ gconf_handle_oaf_exception(CORBA_Environment* ev, GError** err)
       break;
     case CORBA_SYSTEM_EXCEPTION:
       if (err)
-        *err = gconf_error_new(GCONF_ERROR_NO_SERVER, _("CORBA error: %s"),
-                               CORBA_exception_id(ev));
-      CORBA_exception_free(ev);
+        *err = gconf_error_new (GCONF_ERROR_NO_SERVER, _("CORBA error: %s"),
+                                CORBA_exception_id (ev));
+      CORBA_exception_free (ev);
       return TRUE;
       break;
 
@@ -2171,21 +2176,21 @@ gconf_handle_oaf_exception(CORBA_Environment* ev, GError** err)
             OAF_GeneralError* ge = CORBA_exception_value(ev);
 
             if (err)
-              *err = gconf_error_new(GCONF_ERROR_OAF_ERROR,
-                                     _("OAF problem description: '%s'"),
-                                     ge->description);
+              *err = gconf_error_new (GCONF_ERROR_OAF_ERROR,
+                                      _("OAF problem description: '%s'"),
+                                      ge->description);
           }
-        else if (strcmp(id,"IDL:OAF/ActivationContext/NotListed:1.0" ) == 0)
+        else if (strcmp (id,"IDL:OAF/ActivationContext/NotListed:1.0" ) == 0)
           {
             if (err)
               *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("attempt to remove not-listed OAF object directory"));
           }
-        else if (strcmp(id,"IDL:OAF/ActivationContext/AlreadyListed:1.0" ) == 0)
+        else if (strcmp (id,"IDL:OAF/ActivationContext/AlreadyListed:1.0" ) == 0)
           {
             if (err)
               *err = gconf_error_new(GCONF_ERROR_OAF_ERROR, _("attempt to add already-listed OAF directory")); 
           }
-        else if (strcmp(id,"IDL:OAF/ActivationContext/ParseFailed:1.0") == 0)
+        else if (strcmp (id,"IDL:OAF/ActivationContext/ParseFailed:1.0") == 0)
           {
             OAF_ActivationContext_ParseFailed* pe = CORBA_exception_value(ev);
             
@@ -2250,16 +2255,20 @@ gconf_lock_destroy(GConfLock* lock)
 }
 
 GConfLock*
-gconf_get_lock(const gchar* lock_directory,
-               GError** err)
+gconf_get_lock_or_current_holder (const gchar*  lock_directory,
+                                  ConfigServer* current_server,
+                                  GError**      err)
 {
   GConfLock* lock;
   gboolean got_it = FALSE;
   gboolean error_occurred = FALSE;
   gboolean stale = FALSE;
   gchar* iorfile;
+  ConfigServer server;
   
   g_return_val_if_fail(lock_directory != NULL, NULL);
+
+  server = CORBA_OBJECT_NIL;
   
   lock = g_new(GConfLock, 1);
 
@@ -2327,7 +2336,6 @@ gconf_get_lock(const gchar* lock_directory,
                 }
               else
                 {
-                  ConfigServer server;
                   CORBA_ORB orb;
                   CORBA_Environment ev;
 
@@ -2399,11 +2407,25 @@ gconf_get_lock(const gchar* lock_directory,
  out:
 
   if (error_occurred)
-    {
+    {      
       g_assert(!got_it);
 
       g_free(iorfile);
       gconf_lock_destroy(lock);
+      
+      if (server != CORBA_OBJECT_NIL)
+        {
+          if (current_server)
+            *current_server = server;
+          else
+            {
+              CORBA_Environment ev;
+              CORBA_exception_init (&ev);
+              CORBA_Object_release (server, &ev);
+              CORBA_exception_free (&ev);
+            }
+        }
+
       return NULL;
     }
 
@@ -2482,6 +2504,13 @@ gconf_get_lock(const gchar* lock_directory,
   return lock;
 }
 
+GConfLock*
+gconf_get_lock(const gchar* lock_directory,
+               GError** err)
+{
+  return gconf_get_lock_or_current_holder (lock_directory, NULL, err);
+}
+
 gboolean
 gconf_release_lock(GConfLock* lock,
                    GError** err)
