@@ -295,7 +295,7 @@ gconf_server_load_sources(void)
 
       addresses[1] = NULL;
       
-      gconf_log(GCL_INFO, _("No configuration files found, trying to use the default config source `%s'"), addresses[0]);
+      gconf_log(GCL_DEBUG, _("No configuration files found, trying to use the default config source `%s'"), addresses[0]);
     }
   
   if (addresses == NULL)
@@ -569,8 +569,8 @@ main(int argc, char** argv)
   gconfd_dir = g_strconcat (g_get_home_dir (), "/.gconfd", NULL);
   lock_dir = g_strconcat (gconfd_dir, "/lock", NULL);
 
-  if (mkdir (gconfd_dir, 0700) < 0)
-    gconf_log (GCL_ERR, _("Failed to create %s: %s"),
+  if (mkdir (gconfd_dir, 0700) < 0 && errno != EEXIST)
+    gconf_log (GCL_WARNING, _("Failed to create %s: %s"),
                gconfd_dir, g_strerror (errno));
   
   err = NULL;
